body{
color:black;
/*margin:0%;
margin:0%;*/
text-align:left;
vertical-align:top;
font-family:verdana, sans-serif;
}

td.folderOpen{
background-image:url('/style/green/folderOpen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderClosed{
background-image:url('/style/green/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.minusNode{
background-image:url('/style/green/minusNode.gif');
cursor:pointer;    
}
td.lastMinusNode{
background-image:url('/style/green/lastMinusNode.gif');
cursor:pointer;    
}
td.plusNode{
background-image:url('/style/green/plusNode.gif');
cursor:pointer;    
}
td.lastPlusNode{
background-image:url('/style/green/lastPlusNode.gif');
cursor:pointer;
height:20px; 
}
td.node{
background-image:url('/style/green/node.gif');
cursor:pointer;
font-size:14px;
height:20px;
}
td.submenuDeco{
background-image:url('/style/green/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode{
background-image:url('/style/green/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:14px;
height:20px;
}
a.treeviewLink{
font-size:14px;
color:black;
cursor:pointer;
height:20px;
}
a.treeviewLink:hover{
font-size:14px;
height:20px;
color:blue;
}
a{
font-size:14px;
color:black;
cursor:pointer;
height:20px;
}
a:hover{
font-size:14px;
height:20px;
color:blue;
}
a.Variable_Scalar{
color:#840808;
}

