body{
color:black;
/*margin:0%;
margin:0%;*/
text-align:left;
vertical-align:top;
font-family:verdana, sans-serif;
}

td.folderOpen{
background-image:url('/style/Crystal/folderOpen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderClosed{
background-image:url('/style/Crystal/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderMan{
background-image:url('/style/Crystal/folderMan.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderManClosed{
background-image:url('/style/Crystal/folderMan.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderHtml{
background-image:url('/style/Crystal/folderHtml.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderHtmlClosed{
background-image:url('/style/Crystal/folderHtml.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderFavorite{
background-image:url('/style/Crystal/folderFavorite.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderFavoriteClosed{
background-image:url('/style/Crystal/folderFavorite.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderText{
background-image:url('/style/Crystal/folderText.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderTextClosed{
background-image:url('/style/Crystal/folderText.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderLocked{
background-image:url('/style/Crystal/folderLocked.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderLockedClosed{
background-image:url('/style/Crystal/folderLocked.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderCrystal{
background-image:url('/style/Crystal/folderCrystal.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderCrystalClosed{
background-image:url('/style/Crystal/folderCrystal.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderVideo{
background-image:url('/style/Crystal/folderVideo.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderVideoClosed{
background-image:url('/style/Crystal/folderVideo.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderPrint{
background-image:url('/style/Crystal/folderPrint.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderPrintClosed{
background-image:url('/style/Crystal/folderPrint.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderSentMail{
background-image:url('/style/Crystal/folderSentMail.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderSentMailClosed{
background-image:url('/style/Crystal/folderSentMail.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderImage{
background-image:url('/style/Crystal/folderImage.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderImageClosed{
background-image:url('/style/Crystal/folderImage.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderSound{
background-image:url('/style/Crystal/folderSound.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderSoundClosed{
background-image:url('/style/Crystal/folderSound.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderImportant{
background-image:url('/style/Crystal/folderImportant.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderImportantClosed{
background-image:url('/style/Crystal/folderImportant.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.folderTar{
background-image:url('/style/Crystal/folderTar.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderTarClosed{
background-image:url('/style/Crystal/folderTar.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
color:black;
vertical-align:top;
}
td.minusNode{
background-image:url('/style/Crystal/minusNode.gif');
cursor:pointer;    
}
td.lastMinusNode{
background-image:url('/style/Crystal/lastMinusNode.gif');
cursor:pointer;    
}
td.plusNode{
background-image:url('/style/Crystal/plusNode.gif');
cursor:pointer;    
}
td.lastPlusNode{
background-image:url('/style/Crystal/lastPlusNode.gif');
cursor:pointer;
height:20px; 
}
td.node{
background-image:url('/style/Crystal/node.gif');
cursor:pointer;
font-size:14px;
height:20px;
}
td.submenuDeco{
background-image:url('/style/Crystal/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode{
background-image:url('/style/Crystal/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:14px;
height:20px;
}
a.treeviewLink{
font-size:14px;
color:black;
cursor:pointer;
height:20px;
}
a.treeviewLink:hover{
font-size:14px;
height:20px;
color:blue;
}
a{
font-size:14px;
color:black;
cursor:pointer;
height:20px;
}
a:hover{
font-size:14px;
height:20px;
color:blue;
}

